@@ -22,9 +22,18 @@
 The Torch version of the BSS eval metrics
 """
 from .metrics import (
-    bss_eval_sources,
     square_cosine_metrics,
+    bss_eval_sources,
     sdr_loss,
     pairwise_sdr_loss,
+    sdr_pit_loss,
     sdr,
 )
+
+from .scale_invariant import (
+    si_bss_eval_sources,
+    si_sdr_loss,
+    pairwise_si_sdr_loss,
+    si_sdr_pit_loss,
+    si_sdr,
+)
