@@ -21,7 +21,9 @@
 from typing import Optional, Tuple
 
 import numpy as np
+
 import torch
+
 from .hungarian import linear_sum_assignment
 
 
@@ -49,7 +51,11 @@ def _coherence_to_neg_sdr(
     if clamp_db is not None:
         # clamp within desired decibel range
         eps = _db_clamp_eps(clamp_db)
-        coh = torch.clamp(coh, min=eps, max=1 - eps)
+    else:
+        # theoretically the coh values should be in [0, 1],
+        # so we clamp them there to avoid numerical issues.
+        eps = 0.0
+    coh = torch.clamp(coh, min=eps, max=1 - eps)
 
     ratio = (1 - coh) / coh
 
@@ -113,6 +119,9 @@ def _linear_sum_assignment_with_inf(
     to handle infinite entries in the cost matrix.
     """
 
+    if cost_matrix.numel() == 0:
+        return torch.zeros(0, dtype=torch.int64), torch.zeros(0, dtype=torch.int64)
+
     min_inf = torch.isneginf(cost_matrix).any()
     max_inf = torch.isposinf(cost_matrix).any()
     if min_inf and max_inf:
